import { Client }                     from '@elastic/elasticsearch';
import { Inject }                     from '@nestjs/common';
import { ElasticsearchLoggerOptions } from './ElasticsearchLoggerOptions';

export class ElasticsearchLoggerService {

    private readonly client: Client;
    private readonly prefix: string;

    public constructor(@Inject('CONFIG_OPTIONS') private readonly options: ElasticsearchLoggerOptions) {

        console.log(options);

        this.client = new Client(options.elasticsearchClientOptions);

    }

    /**
     * Primary log message handler.
     *
     * @param {string} level
     * @param args
     */
    private log(level: string, args): void {

        this.client.index({

            index: this.options.index,
            body: {

                date: new Date().toUTCString(),
                log: args

            }

        });

        if (this.options.stdout) {

            console.log(`[${ this.options.name }] ${ JSON.stringify(args) }`);

        }

    }

    public info(...args): void {

        console.log(args);

        this.log('info', args);

    }

}
